@@ -17,13 +17,7 @@ print(f'[{time.ctime()}][main/Info] module colorama inited')
 print(f'[{time.ctime()}][main/Info] modules initlazed')
 
 Ui_MainWindow,_ = loadUiType('downloader.ui')
-Ui_MainWindow2,_ = loadUiType('about.ui')
-class window2(QtWidgets.QMainWindow,Ui_MainWindow2):
-    def __init__(self):
-        super(window2,self).__init__()
-        self.setupUi(self)
-        self.pushButton.clicked.connect(self.close)
-        self.setWindowIcon(QIcon('icon.bmp'))
+
 
 
 
@@ -39,7 +33,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.te = ''
         self.progressBar.setValue(0)
         self.pushButton_2.clicked.connect(self.fwa)
-        self.pushButton_3.clicked.connect(self.about)
+
 
 
         self.setWindowIcon(QIcon('icon.bmp'))
@@ -60,8 +54,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.timer.timeout.connect(self.write)
         self.timer.start(500)
         print(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
-    def about(self):
-        self.signal.emit()
+
     def opencmd(self):
         os.system('cmd')
     def fwa(self):
@@ -220,12 +213,11 @@ if __name__ == '__main__':
     app = QtWidgets.QApplication(sys.argv)
     window = window()
     window.show()
-    window2=window2()
-    window.signal.connect(window2.show)
+
     sys.exit(app.exec_())
 else:
     print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
-    run('v0.6')
+    run('v0.8')
 
 
 
